@@ -5,7 +5,7 @@ use warnings;
 
 package Net::Fritz::Service;
 # ABSTRACT: represents a TR064 service
-$Net::Fritz::Service::VERSION = 'v0.0.6';
+$Net::Fritz::Service::VERSION = 'v0.0.7';
 
 use Digest::MD5 qw(md5_hex);
 use SOAP::Lite; # +trace => [ transport => sub { print $_[0]->as_string } ]; # TODO: remove
@@ -49,7 +49,7 @@ sub _build_scpd {
 
     if ($response->is_success) {
 	return Net::Fritz::Data->new(
-	    $self->fritz->_xs->xml_in($response->decoded_content)
+	    $self->fritz->_xs->parse_string($response->decoded_content)
 	    );
     }
     else {
@@ -318,7 +318,7 @@ Net::Fritz::Service - represents a TR064 service
 
 =head1 VERSION
 
-version v0.0.6
+version v0.0.7
 
 =head1 SYNOPSIS
 
